#!/bin/bash
set -e
INSTALLER_DIR=$(dirname "${BASH_SOURCE[0]}")
HELPER_SCRIPTS_DIR="$INSTALLER_DIR/helper_scripts"

source "$HELPER_SCRIPTS_DIR/packages.sh"
source "$HELPER_SCRIPTS_DIR/command_exists.sh"

NONE_IDENTIFIER="none"
NONE_TEXT="None"

declare -A GIT_EDITORS
GIT_EDITORS=(
    ["$SNAP_VSCODE_PACKAGE"]="${PACKAGES["$SNAP_VSCODE_PACKAGE"]}"
    ["$NONE_IDENTIFIER"]="$NONE_TEXT"
)

ORDERED_GIT_EDITORS=(
    "$NONE_IDENTIFIER"
    "$SNAP_VSCODE_PACKAGE"
)

declare -A GIT_DIFFTOOLS
GIT_DIFFTOOLS=(
    ["$SNAP_VSCODE_PACKAGE"]="${PACKAGES["$SNAP_VSCODE_PACKAGE"]}"
    ["$NONE_IDENTIFIER"]="$NONE_TEXT"
)

ORDERED_GIT_DIFFTOOLS=(
    "$NONE_IDENTIFIER"
    "$SNAP_VSCODE_PACKAGE"
)

declare -A GIT_MERGETOOLS
GIT_MERGETOOLS=(
    ["$SNAP_VSCODE_PACKAGE"]="${PACKAGES["$SNAP_VSCODE_PACKAGE"]}"
    ["$NONE_IDENTIFIER"]="$NONE_TEXT"
)

ORDERED_GIT_MERGETOOLS=(
    "$NONE_IDENTIFIER"
    "$SNAP_VSCODE_PACKAGE"
)

SWAP_DEFAULT_UNIT="G"

main() {
    read -e -p "DConf config (empty to skip): " dconf_config_path
    read -e -p "Visual Studio Code User Settings (empty to skip): " vscode_config_path
    read -e -p "Visual Studio Code Extensions File (empty to skip): " vscode_extensions_path
    read -e -p "Git Config (empty to skip): " git_config_path
    read -e -p "Comma separated swap sizes in Gigabytes (empty to skip): " swap_sizes
    swap_sizes="${swap_sizes//','/"$SWAP_DEFAULT_UNIT "}"

    if [[ -n "$swap_sizes" ]]; then
        swap_sizes+="$SWAP_DEFAULT_UNIT"
    fi

    additional_ansible_args=()
    if [[ -n "$swap_sizes" || -n "$git_config_path" || -n "$dconf_config_path" ]]; then
        additional_ansible_args+=('--ask-become-pass')
    fi

    bash $HELPER_SCRIPTS_DIR/install_ansible.sh
    ansible-playbook "${INSTALLER_DIR}/playbooks/setup.yaml" \
        --extra-vars "dconf_config_path='$dconf_config_path' vscode_config_path='$vscode_config_path' vscode_extensions_path='$vscode_extensions_path' swap_sizes='$swap_sizes' git_config_path='$git_config_path'" \
        --inventory "${INSTALLER_DIR}/ansible_inventory.ini" \
        $(IFS=' ' echo "${additional_ansible_args[*]}")

    if command_exists flatpak; then
        echo "If you have set your system theme to dark, you may need to update your Flatpak packages. You can use update.sh to do so."
    fi
}

main
