#!/bin/bash
set -e
INSTALLER_DIR=$(dirname "${BASH_SOURCE[0]}")
HELPER_SCRIPTS_DIR="$INSTALLER_DIR/helper_scripts"

source "$HELPER_SCRIPTS_DIR/package_manager_identifiers.sh"
source "$HELPER_SCRIPTS_DIR/command_exists.sh"

declare -A PACKAGE_MANAGERS
PACKAGE_MANAGERS=(
    ["$APT_IDENTIFIER"]="APT"
    ["$SNAP_IDENTIFIER"]="Snap"
    ["$FLATPAK_IDENTIFIER"]="Flatpak"
    ["$MAINLINE_KERNEL_IDENTIFIER"]="Mainline Kernel"
)

DEFAULT_PACKAGE_MANAGERS=(
    "$APT_IDENTIFIER"
)

ORDERED_PACKAGE_MANAGERS=(
    "$APT_IDENTIFIER"
    "$FLATPAK_IDENTIFIER"
    "$SNAP_IDENTIFIER"
    "$MAINLINE_KERNEL_IDENTIFIER"
)

main() {
    possible_package_managers=("${DEFAULT_PACKAGE_MANAGERS[@]}")

    if command_exists flatpak; then
        possible_package_managers+=("$FLATPAK_IDENTIFIER")
    fi

    if command_exists snap; then
        possible_package_managers+=("$SNAP_IDENTIFIER")
    fi

    if command_exists mainline; then
        possible_package_managers+=("$MAINLINE_KERNEL_IDENTIFIER")
    fi

    update_package_managers=$(for package_manager in "${ORDERED_PACKAGE_MANAGERS[@]}"; do
        for possible_package_manager in "${possible_package_managers[@]}"; do
            if [[ "$package_manager" == "$possible_package_manager" ]]; then
                echo "true"
                echo "${PACKAGE_MANAGERS["$package_manager"]}"
                echo "$package_manager"
            fi
        done
    done | zenity --list \
        --title="Update Selection" \
        --text="Select package managers to update:" \
        --checklist \
        --column="Update" --column="Package Manager" --column="Identifier" \
        --print-column "3" \
        --width=600 --height=400 \
        2>/dev/null # suppress file descriptor error
    )

    update_package_managers="${update_package_managers//|/' '}"

    # Update packages using ansible
    bash $HELPER_SCRIPTS_DIR/install_ansible.sh
    ansible-playbook "${INSTALLER_DIR}/playbooks/update_packages.yaml" \
        --extra-vars "package_managers='$update_package_managers'" \
        --inventory "${INSTALLER_DIR}/ansible_inventory.ini" \
        --ask-become-pass
}

main

# set -e
# source installer_vars.sh
# source source_if_options_not_sourced.sh
# source install_functions.sh
# source_if_options_not_sourced

# check_if_root
# update_upgrade
